Readable

Trait Readable 

pub trait Readable: RegisterSpec {
    type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also modify’ed.

Required Associated Types

type Reader: From<R<Self>> + Deref<Target = R<Self>>

Result from a call to read and argument to modify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Readable for CALIB_SPEC

read() method returns calib::R reader structure

Source

impl Readable for swm341_pac::adc0::cr2::CR2_SPEC

read() method returns cr2::R reader structure

Source

impl Readable for swm341_pac::adc0::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::adc0::go::GO_SPEC

read() method returns go::R reader structure

Source

impl Readable for swm341_pac::adc0::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::adc0::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::adc0::seq0::cmp::CMP_SPEC

read() method returns cmp::R reader structure

Source

impl Readable for swm341_pac::adc0::seq0::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq0::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq1::cmp::CMP_SPEC

read() method returns cmp::R reader structure

Source

impl Readable for swm341_pac::adc0::seq1::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq1::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq2::cmp::CMP_SPEC

read() method returns cmp::R reader structure

Source

impl Readable for swm341_pac::adc0::seq2::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq2::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq3::cmp::CMP_SPEC

read() method returns cmp::R reader structure

Source

impl Readable for swm341_pac::adc0::seq3::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for swm341_pac::adc0::seq3::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for SEQCHN0_SPEC

read() method returns seqchn0::R reader structure

Source

impl Readable for SEQCHN1_SPEC

read() method returns seqchn1::R reader structure

Source

impl Readable for SEQCOV_SPEC

read() method returns seqcov::R reader structure

Source

impl Readable for SEQSMP_SPEC

read() method returns seqsmp::R reader structure

Source

impl Readable for SEQTRG_SPEC

read() method returns seqtrg::R reader structure

Source

impl Readable for ACR_SPEC

read() method returns acr::R reader structure

Source

impl Readable for AFE_SPEC

read() method returns afe::R reader structure

Source

impl Readable for AFM_SPEC

read() method returns afm::R reader structure

Source

impl Readable for ALC_SPEC

read() method returns alc::R reader structure

Source

impl Readable for AMR_SPEC

read() method returns amr::R reader structure

Source

impl Readable for BT0_SPEC

read() method returns bt0::R reader structure

Source

impl Readable for BT1_SPEC

read() method returns bt1::R reader structure

Source

impl Readable for BT2_SPEC

read() method returns bt2::R reader structure

Source

impl Readable for swm341_pac::can0::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for ECC_SPEC

read() method returns ecc::R reader structure

Source

impl Readable for EWLIM_SPEC

read() method returns ewlim::R reader structure

Source

impl Readable for swm341_pac::can0::frame::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for INFO_SPEC

read() method returns info::R reader structure

Source

impl Readable for swm341_pac::can0::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::can0::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for RMCNT_SPEC

read() method returns rmcnt::R reader structure

Source

impl Readable for RXERR_SPEC

read() method returns rxerr::R reader structure

Source

impl Readable for swm341_pac::can0::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for TXERR_SPEC

read() method returns txerr::R reader structure

Source

impl Readable for ARCTAN_SPEC

read() method returns arctan::R reader structure

Source

impl Readable for swm341_pac::cordic::cmd::CMD_SPEC

read() method returns cmd::R reader structure

Source

impl Readable for COS_SPEC

read() method returns cos::R reader structure

Source

impl Readable for swm341_pac::cordic::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::cordic::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for INPUT_SPEC

read() method returns input::R reader structure

Source

impl Readable for SIN_SPEC

read() method returns sin::R reader structure

Source

impl Readable for TANH_SPEC

read() method returns tanh::R reader structure

Source

impl Readable for swm341_pac::crc::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for INIVAL_SPEC

read() method returns inival::R reader structure

Source

impl Readable for RESULT_SPEC

read() method returns result::R reader structure

Source

impl Readable for swm341_pac::dac::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DHR_SPEC

read() method returns dhr::R reader structure

Source

impl Readable for swm341_pac::dac::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::div::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DIVIDEND_SPEC

read() method returns dividend::R reader structure

Source

impl Readable for DIVISOR_SPEC

read() method returns divisor::R reader structure

Source

impl Readable for QUO_SPEC

read() method returns quo::R reader structure

Source

impl Readable for RADICAND_SPEC

read() method returns radicand::R reader structure

Source

impl Readable for REMAIN_SPEC

read() method returns remain::R reader structure

Source

impl Readable for ROOT_SPEC

read() method returns root::R reader structure

Source

impl Readable for swm341_pac::div::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::dma2d::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::dma2d::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::dma2d::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::dma2d::l0::color::COLOR_SPEC

read() method returns color::R reader structure

Source

impl Readable for swm341_pac::dma2d::l0::mar::MAR_SPEC

read() method returns mar::R reader structure

Source

impl Readable for swm341_pac::dma2d::l0::or::OR_SPEC

read() method returns or::R reader structure

Source

impl Readable for swm341_pac::dma2d::l0::pfccr::PFCCR_SPEC

read() method returns pfccr::R reader structure

Source

impl Readable for swm341_pac::dma2d::l1::color::COLOR_SPEC

read() method returns color::R reader structure

Source

impl Readable for swm341_pac::dma2d::l1::mar::MAR_SPEC

read() method returns mar::R reader structure

Source

impl Readable for swm341_pac::dma2d::l1::or::OR_SPEC

read() method returns or::R reader structure

Source

impl Readable for swm341_pac::dma2d::l1::pfccr::PFCCR_SPEC

read() method returns pfccr::R reader structure

Source

impl Readable for swm341_pac::dma2d::l2::color::COLOR_SPEC

read() method returns color::R reader structure

Source

impl Readable for swm341_pac::dma2d::l2::mar::MAR_SPEC

read() method returns mar::R reader structure

Source

impl Readable for swm341_pac::dma2d::l2::or::OR_SPEC

read() method returns or::R reader structure

Source

impl Readable for swm341_pac::dma2d::l2::pfccr::PFCCR_SPEC

read() method returns pfccr::R reader structure

Source

impl Readable for NLR_SPEC

read() method returns nlr::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::am::AM_SPEC

read() method returns am::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::dst::DST_SPEC

read() method returns dst::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::dstsgaddr1::DSTSGADDR1_SPEC

read() method returns dstsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::dstsgaddr2::DSTSGADDR2_SPEC

read() method returns dstsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::dstsgaddr3::DSTSGADDR3_SPEC

read() method returns dstsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::dstsr::DSTSR_SPEC

read() method returns dstsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::mux::MUX_SPEC

read() method returns mux::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::src::SRC_SPEC

read() method returns src::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::srcsgaddr1::SRCSGADDR1_SPEC

read() method returns srcsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::srcsgaddr2::SRCSGADDR2_SPEC

read() method returns srcsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::srcsgaddr3::SRCSGADDR3_SPEC

read() method returns srcsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch0::srcsr::SRCSR_SPEC

read() method returns srcsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::am::AM_SPEC

read() method returns am::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::dst::DST_SPEC

read() method returns dst::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::dstsgaddr1::DSTSGADDR1_SPEC

read() method returns dstsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::dstsgaddr2::DSTSGADDR2_SPEC

read() method returns dstsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::dstsgaddr3::DSTSGADDR3_SPEC

read() method returns dstsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::dstsr::DSTSR_SPEC

read() method returns dstsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::mux::MUX_SPEC

read() method returns mux::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::src::SRC_SPEC

read() method returns src::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::srcsgaddr1::SRCSGADDR1_SPEC

read() method returns srcsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::srcsgaddr2::SRCSGADDR2_SPEC

read() method returns srcsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::srcsgaddr3::SRCSGADDR3_SPEC

read() method returns srcsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch1::srcsr::SRCSR_SPEC

read() method returns srcsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::am::AM_SPEC

read() method returns am::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::dst::DST_SPEC

read() method returns dst::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::dstsgaddr1::DSTSGADDR1_SPEC

read() method returns dstsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::dstsgaddr2::DSTSGADDR2_SPEC

read() method returns dstsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::dstsgaddr3::DSTSGADDR3_SPEC

read() method returns dstsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::dstsr::DSTSR_SPEC

read() method returns dstsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::mux::MUX_SPEC

read() method returns mux::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::src::SRC_SPEC

read() method returns src::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::srcsgaddr1::SRCSGADDR1_SPEC

read() method returns srcsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::srcsgaddr2::SRCSGADDR2_SPEC

read() method returns srcsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::srcsgaddr3::SRCSGADDR3_SPEC

read() method returns srcsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch2::srcsr::SRCSR_SPEC

read() method returns srcsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::am::AM_SPEC

read() method returns am::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::dst::DST_SPEC

read() method returns dst::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::dstsgaddr1::DSTSGADDR1_SPEC

read() method returns dstsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::dstsgaddr2::DSTSGADDR2_SPEC

read() method returns dstsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::dstsgaddr3::DSTSGADDR3_SPEC

read() method returns dstsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::dstsr::DSTSR_SPEC

read() method returns dstsr::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::mux::MUX_SPEC

read() method returns mux::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::src::SRC_SPEC

read() method returns src::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::srcsgaddr1::SRCSGADDR1_SPEC

read() method returns srcsgaddr1::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::srcsgaddr2::SRCSGADDR2_SPEC

read() method returns srcsgaddr2::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::srcsgaddr3::SRCSGADDR3_SPEC

read() method returns srcsgaddr3::R reader structure

Source

impl Readable for swm341_pac::dma::ch3::srcsr::SRCSR_SPEC

read() method returns srcsr::R reader structure

Source

impl Readable for DSTSGIE_SPEC

read() method returns dstsgie::R reader structure

Source

impl Readable for DSTSGIF_SPEC

read() method returns dstsgif::R reader structure

Source

impl Readable for DSTSGIM_SPEC

read() method returns dstsgim::R reader structure

Source

impl Readable for swm341_pac::dma::en::EN_SPEC

read() method returns en::R reader structure

Source

impl Readable for swm341_pac::dma::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::dma::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::dma::im::IM_SPEC

read() method returns im::R reader structure

Source

impl Readable for PRI_SPEC

read() method returns pri::R reader structure

Source

impl Readable for SRCSGIE_SPEC

read() method returns srcsgie::R reader structure

Source

impl Readable for SRCSGIF_SPEC

read() method returns srcsgif::R reader structure

Source

impl Readable for SRCSGIM_SPEC

read() method returns srcsgim::R reader structure

Source

impl Readable for swm341_pac::fmc::addr::ADDR_SPEC

read() method returns addr::R reader structure

Source

impl Readable for CACHE_SPEC

read() method returns cache::R reader structure

Source

impl Readable for CFG0_SPEC

read() method returns cfg0::R reader structure

Source

impl Readable for CFG1_SPEC

read() method returns cfg1::R reader structure

Source

impl Readable for CFG2_SPEC

read() method returns cfg2::R reader structure

Source

impl Readable for CFG3_SPEC

read() method returns cfg3::R reader structure

Source

impl Readable for CFG4_SPEC

read() method returns cfg4::R reader structure

Source

impl Readable for swm341_pac::fmc::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for ERASE_SPEC

read() method returns erase::R reader structure

Source

impl Readable for swm341_pac::fmc::stat::STAT_SPEC

read() method returns stat::R reader structure

Source

impl Readable for DATAPIN0_SPEC

read() method returns datapin0::R reader structure

Source

impl Readable for DATAPIN1_SPEC

read() method returns datapin1::R reader structure

Source

impl Readable for DATAPIN2_SPEC

read() method returns datapin2::R reader structure

Source

impl Readable for DATAPIN3_SPEC

read() method returns datapin3::R reader structure

Source

impl Readable for DATAPIN4_SPEC

read() method returns datapin4::R reader structure

Source

impl Readable for DATAPIN5_SPEC

read() method returns datapin5::R reader structure

Source

impl Readable for DATAPIN6_SPEC

read() method returns datapin6::R reader structure

Source

impl Readable for DATAPIN7_SPEC

read() method returns datapin7::R reader structure

Source

impl Readable for DATAPIN8_SPEC

read() method returns datapin8::R reader structure

Source

impl Readable for DATAPIN9_SPEC

read() method returns datapin9::R reader structure

Source

impl Readable for DATAPIN10_SPEC

read() method returns datapin10::R reader structure

Source

impl Readable for DATAPIN11_SPEC

read() method returns datapin11::R reader structure

Source

impl Readable for DATAPIN12_SPEC

read() method returns datapin12::R reader structure

Source

impl Readable for DATAPIN13_SPEC

read() method returns datapin13::R reader structure

Source

impl Readable for DATAPIN14_SPEC

read() method returns datapin14::R reader structure

Source

impl Readable for DATAPIN15_SPEC

read() method returns datapin15::R reader structure

Source

impl Readable for DIR_SPEC

read() method returns dir::R reader structure

Source

impl Readable for DMAEN_SPEC

read() method returns dmaen::R reader structure

Source

impl Readable for IDR_SPEC

read() method returns idr::R reader structure

Source

impl Readable for INTBE_SPEC

read() method returns intbe::R reader structure

Source

impl Readable for INTCLR_SPEC

read() method returns intclr::R reader structure

Source

impl Readable for INTEN_SPEC

read() method returns inten::R reader structure

Source

impl Readable for INTLVLTRG_SPEC

read() method returns intlvltrg::R reader structure

Source

impl Readable for INTRAWSTAT_SPEC

read() method returns intrawstat::R reader structure

Source

impl Readable for INTRISEEN_SPEC

read() method returns intriseen::R reader structure

Source

impl Readable for INTSTAT_SPEC

read() method returns intstat::R reader structure

Source

impl Readable for ODR_SPEC

read() method returns odr::R reader structure

Source

impl Readable for CLK_SPEC

read() method returns clk::R reader structure

Source

impl Readable for swm341_pac::i2c0::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::i2c0::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::i2c0::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for MCR_SPEC

read() method returns mcr::R reader structure

Source

impl Readable for RXDATA_SPEC

read() method returns rxdata::R reader structure

Source

impl Readable for SADDR_SPEC

read() method returns saddr::R reader structure

Source

impl Readable for SCR_SPEC

read() method returns scr::R reader structure

Source

impl Readable for swm341_pac::i2c0::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for TR_SPEC

read() method returns tr::R reader structure

Source

impl Readable for TXDATA_SPEC

read() method returns txdata::R reader structure

Source

impl Readable for swm341_pac::jpeg::cfg::CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for CODLEN_SPEC

read() method returns codlen::R reader structure

Source

impl Readable for swm341_pac::jpeg::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for CSBASE_SPEC

read() method returns csbase::R reader structure

Source

impl Readable for HTBASE_SPEC

read() method returns htbase::R reader structure

Source

impl Readable for IMGSIZ_SPEC

read() method returns imgsiz::R reader structure

Source

impl Readable for IMGSTR_SPEC

read() method returns imgstr::R reader structure

Source

impl Readable for IR_SPEC

read() method returns ir::R reader structure

Source

impl Readable for QTBASE_SPEC

read() method returns qtbase::R reader structure

Source

impl Readable for RGBASE_SPEC

read() method returns rgbase::R reader structure

Source

impl Readable for swm341_pac::jpeg::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for UBASE_SPEC

read() method returns ubase::R reader structure

Source

impl Readable for VBASE_SPEC

read() method returns vbase::R reader structure

Source

impl Readable for YBASE_SPEC

read() method returns ybase::R reader structure

Source

impl Readable for BGC_SPEC

read() method returns bgc::R reader structure

Source

impl Readable for swm341_pac::lcd::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for CRH_SPEC

read() method returns crh::R reader structure

Source

impl Readable for CRV_SPEC

read() method returns crv::R reader structure

Source

impl Readable for swm341_pac::lcd::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::lcd::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::lcd::l0::addr::ADDR_SPEC

read() method returns addr::R reader structure

Source

impl Readable for swm341_pac::lcd::l0::ck::CK_SPEC

read() method returns ck::R reader structure

Source

impl Readable for swm341_pac::lcd::l0::lcr::LCR_SPEC

read() method returns lcr::R reader structure

Source

impl Readable for swm341_pac::lcd::l0::llen::LLEN_SPEC

read() method returns llen::R reader structure

Source

impl Readable for swm341_pac::lcd::l0::whp::WHP_SPEC

read() method returns whp::R reader structure

Source

impl Readable for swm341_pac::lcd::l0::wvp::WVP_SPEC

read() method returns wvp::R reader structure

Source

impl Readable for swm341_pac::lcd::l1::addr::ADDR_SPEC

read() method returns addr::R reader structure

Source

impl Readable for swm341_pac::lcd::l1::ck::CK_SPEC

read() method returns ck::R reader structure

Source

impl Readable for swm341_pac::lcd::l1::lcr::LCR_SPEC

read() method returns lcr::R reader structure

Source

impl Readable for swm341_pac::lcd::l1::llen::LLEN_SPEC

read() method returns llen::R reader structure

Source

impl Readable for swm341_pac::lcd::l1::whp::WHP_SPEC

read() method returns whp::R reader structure

Source

impl Readable for swm341_pac::lcd::l1::wvp::WVP_SPEC

read() method returns wvp::R reader structure

Source

impl Readable for MPUAR_SPEC

read() method returns mpuar::R reader structure

Source

impl Readable for MPUCR_SPEC

read() method returns mpucr::R reader structure

Source

impl Readable for MPUDR_SPEC

read() method returns mpudr::R reader structure

Source

impl Readable for MPUIR_SPEC

read() method returns mpuir::R reader structure

Source

impl Readable for MPULEN_SPEC

read() method returns mpulen::R reader structure

Source

impl Readable for swm341_pac::lcd::reserved2::RESERVED2_SPEC

read() method returns reserved2::R reader structure

Source

impl Readable for swm341_pac::lcd::start::START_SPEC

read() method returns start::R reader structure

Source

impl Readable for DRVST_SPEC

read() method returns drvst::R reader structure

Source

impl Readable for FUNC0_SPEC

read() method returns func0::R reader structure

Source

impl Readable for FUNC1_SPEC

read() method returns func1::R reader structure

Source

impl Readable for INEN_SPEC

read() method returns inen::R reader structure

Source

impl Readable for OPEND_SPEC

read() method returns opend::R reader structure

Source

impl Readable for PULLD_SPEC

read() method returns pulld::R reader structure

Source

impl Readable for PULLU_SPEC

read() method returns pullu::R reader structure

Source

impl Readable for BRKCR_SPEC

read() method returns brkcr::R reader structure

Source

impl Readable for BRKIN_SPEC

read() method returns brkin::R reader structure

Source

impl Readable for CMPA2_SPEC

read() method returns cmpa2::R reader structure

Source

impl Readable for CMPA_SPEC

read() method returns cmpa::R reader structure

Source

impl Readable for CMPB2_SPEC

read() method returns cmpb2::R reader structure

Source

impl Readable for CMPB_SPEC

read() method returns cmpb::R reader structure

Source

impl Readable for CMPTRG_SPEC

read() method returns cmptrg::R reader structure

Source

impl Readable for swm341_pac::pwm0::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DZA_SPEC

read() method returns dza::R reader structure

Source

impl Readable for DZB_SPEC

read() method returns dzb::R reader structure

Source

impl Readable for EVMSK_SPEC

read() method returns evmsk::R reader structure

Source

impl Readable for EVMUX_SPEC

read() method returns evmux::R reader structure

Source

impl Readable for swm341_pac::pwm0::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::pwm0::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for OCR_SPEC

read() method returns ocr::R reader structure

Source

impl Readable for OVFTRG_SPEC

read() method returns ovftrg::R reader structure

Source

impl Readable for PERIOD_SPEC

read() method returns period::R reader structure

Source

impl Readable for swm341_pac::pwm0::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::pwm0::value::VALUE_SPEC

read() method returns value::R reader structure

Source

impl Readable for BRKIE_SPEC

read() method returns brkie::R reader structure

Source

impl Readable for BRKIF_SPEC

read() method returns brkif::R reader structure

Source

impl Readable for BRKPOL_SPEC

read() method returns brkpol::R reader structure

Source

impl Readable for BRKSR_SPEC

read() method returns brksr::R reader structure

Source

impl Readable for EVSR_SPEC

read() method returns evsr::R reader structure

Source

impl Readable for FILTER_SPEC

read() method returns filter::R reader structure

Source

impl Readable for PULSE_SPEC

read() method returns pulse::R reader structure

Source

impl Readable for RELOADEN_SPEC

read() method returns reloaden::R reader structure

Source

impl Readable for RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for RESTART_SPEC

read() method returns restart::R reader structure

Source

impl Readable for swm341_pac::pwmg::start::START_SPEC

read() method returns start::R reader structure

Source

impl Readable for SWBRK_SPEC

read() method returns swbrk::R reader structure

Source

impl Readable for swm341_pac::qei::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::qei::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::qei::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for IFOV_SPEC

read() method returns ifov::R reader structure

Source

impl Readable for swm341_pac::qei::im::IM_SPEC

read() method returns im::R reader structure

Source

impl Readable for MAXCNT_SPEC

read() method returns maxcnt::R reader structure

Source

impl Readable for POSCNT_SPEC

read() method returns poscnt::R reader structure

Source

impl Readable for CFGABLE_SPEC

read() method returns cfgable::R reader structure

Source

impl Readable for DATHUR_SPEC

read() method returns dathur::R reader structure

Source

impl Readable for DAYHURAL_SPEC

read() method returns dayhural::R reader structure

Source

impl Readable for swm341_pac::rtc::en::EN_SPEC

read() method returns en::R reader structure

Source

impl Readable for swm341_pac::rtc::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::rtc::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::rtc::load::LOAD_SPEC

read() method returns load::R reader structure

Source

impl Readable for MINSEC_SPEC

read() method returns minsec::R reader structure

Source

impl Readable for MINSECAL_SPEC

read() method returns minsecal::R reader structure

Source

impl Readable for MONDAY_SPEC

read() method returns monday::R reader structure

Source

impl Readable for TRIM_SPEC

read() method returns trim::R reader structure

Source

impl Readable for TRIMM_SPEC

read() method returns trimm::R reader structure

Source

impl Readable for YEAR_SPEC

read() method returns year::R reader structure

Source

impl Readable for ARG_SPEC

read() method returns arg::R reader structure

Source

impl Readable for BLK_SPEC

read() method returns blk::R reader structure

Source

impl Readable for CMD12ERR_SPEC

read() method returns cmd12err::R reader structure

Source

impl Readable for swm341_pac::sdio::cmd::CMD_SPEC

read() method returns cmd::R reader structure

Source

impl Readable for CR1_SPEC

read() method returns cr1::R reader structure

Source

impl Readable for swm341_pac::sdio::cr2::CR2_SPEC

read() method returns cr2::R reader structure

Source

impl Readable for swm341_pac::sdio::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for DMA_MEM_ADDR_SPEC

read() method returns dma_mem_addr::R reader structure

Source

impl Readable for swm341_pac::sdio::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::sdio::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::sdio::im::IM_SPEC

read() method returns im::R reader structure

Source

impl Readable for RESP_SPEC

read() method returns resp::R reader structure

Source

impl Readable for swm341_pac::sdio::stat::STAT_SPEC

read() method returns stat::R reader structure

Source

impl Readable for swm341_pac::sdramc::cfg::CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for swm341_pac::sdramc::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for swm341_pac::sdramc::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for T64_SPEC

read() method returns t64::R reader structure

Source

impl Readable for swm341_pac::sdramc::tim::TIM_SPEC

read() method returns tim::R reader structure

Source

impl Readable for swm341_pac::sfc::addr::ADDR_SPEC

read() method returns addr::R reader structure

Source

impl Readable for swm341_pac::sfc::cfg::CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for swm341_pac::sfc::cmd::CMD_SPEC

read() method returns cmd::R reader structure

Source

impl Readable for CMDAHB_SPEC

read() method returns cmdahb::R reader structure

Source

impl Readable for swm341_pac::sfc::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for swm341_pac::sfc::go::GO_SPEC

read() method returns go::R reader structure

Source

impl Readable for swm341_pac::sfc::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::sfc::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::sfc::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for swm341_pac::sfc::tim::TIM_SPEC

read() method returns tim::R reader structure

Source

impl Readable for swm341_pac::spi0::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for swm341_pac::spi0::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for I2SCR_SPEC

read() method returns i2scr::R reader structure

Source

impl Readable for I2SPR_SPEC

read() method returns i2spr::R reader structure

Source

impl Readable for swm341_pac::spi0::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::spi0::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::spi0::stat::STAT_SPEC

read() method returns stat::R reader structure

Source

impl Readable for ACMPCR2_SPEC

read() method returns acmpcr2::R reader structure

Source

impl Readable for ACMPCR_SPEC

read() method returns acmpcr::R reader structure

Source

impl Readable for ACMPSR_SPEC

read() method returns acmpsr::R reader structure

Source

impl Readable for ADCCR_SPEC

read() method returns adccr::R reader structure

Source

impl Readable for BACKUP_SPEC

read() method returns backup::R reader structure

Source

impl Readable for BODCR_SPEC

read() method returns bodcr::R reader structure

Source

impl Readable for BODSR_SPEC

read() method returns bodsr::R reader structure

Source

impl Readable for CHIPID_SPEC

read() method returns chipid::R reader structure

Source

impl Readable for CLKDIVX_ON_SPEC

read() method returns clkdivx_on::R reader structure

Source

impl Readable for CLKEN0_SPEC

read() method returns clken0::R reader structure

Source

impl Readable for CLKEN1_SPEC

read() method returns clken1::R reader structure

Source

impl Readable for CLKSEL_SPEC

read() method returns clksel::R reader structure

Source

impl Readable for DACCR_SPEC

read() method returns daccr::R reader structure

Source

impl Readable for HRCCR_SPEC

read() method returns hrccr::R reader structure

Source

impl Readable for IOFILT0_SPEC

read() method returns iofilt0::R reader structure

Source

impl Readable for IOFILT1_SPEC

read() method returns iofilt1::R reader structure

Source

impl Readable for LRCCR_SPEC

read() method returns lrccr::R reader structure

Source

impl Readable for OPACR_SPEC

read() method returns opacr::R reader structure

Source

impl Readable for PAWKEN_SPEC

read() method returns pawken::R reader structure

Source

impl Readable for PAWKSR_SPEC

read() method returns pawksr::R reader structure

Source

impl Readable for PBWKEN_SPEC

read() method returns pbwken::R reader structure

Source

impl Readable for PBWKSR_SPEC

read() method returns pbwksr::R reader structure

Source

impl Readable for PCWKEN_SPEC

read() method returns pcwken::R reader structure

Source

impl Readable for PCWKSR_SPEC

read() method returns pcwksr::R reader structure

Source

impl Readable for PDWKEN_SPEC

read() method returns pdwken::R reader structure

Source

impl Readable for PDWKSR_SPEC

read() method returns pdwksr::R reader structure

Source

impl Readable for PEWKEN_SPEC

read() method returns pewken::R reader structure

Source

impl Readable for PEWKSR_SPEC

read() method returns pewksr::R reader structure

Source

impl Readable for PLLCR_SPEC

read() method returns pllcr::R reader structure

Source

impl Readable for PLLDIV_SPEC

read() method returns plldiv::R reader structure

Source

impl Readable for PLLLOCK_SPEC

read() method returns plllock::R reader structure

Source

impl Readable for PMWKEN_SPEC

read() method returns pmwken::R reader structure

Source

impl Readable for PMWKSR_SPEC

read() method returns pmwksr::R reader structure

Source

impl Readable for PNWKEN_SPEC

read() method returns pnwken::R reader structure

Source

impl Readable for PNWKSR_SPEC

read() method returns pnwksr::R reader structure

Source

impl Readable for PRNGCR_SPEC

read() method returns prngcr::R reader structure

Source

impl Readable for PRNGDH_SPEC

read() method returns prngdh::R reader structure

Source

impl Readable for PRNGDL_SPEC

read() method returns prngdl::R reader structure

Source

impl Readable for PRSTEN_SPEC

read() method returns prsten::R reader structure

Source

impl Readable for PRSTR0_SPEC

read() method returns prstr0::R reader structure

Source

impl Readable for PRSTR1_SPEC

read() method returns prstr1::R reader structure

Source

impl Readable for RSTSR_SPEC

read() method returns rstsr::R reader structure

Source

impl Readable for RTCWKCR_SPEC

read() method returns rtcwkcr::R reader structure

Source

impl Readable for RTCWKSR_SPEC

read() method returns rtcwksr::R reader structure

Source

impl Readable for SLEEP_SPEC

read() method returns sleep::R reader structure

Source

impl Readable for TEMPCR_SPEC

read() method returns tempcr::R reader structure

Source

impl Readable for USBCR_SPEC

read() method returns usbcr::R reader structure

Source

impl Readable for USBPHYCR_SPEC

read() method returns usbphycr::R reader structure

Source

impl Readable for XTALCR_SPEC

read() method returns xtalcr::R reader structure

Source

impl Readable for XTALSR_SPEC

read() method returns xtalsr::R reader structure

Source

impl Readable for swm341_pac::timr0::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for HALT_SPEC

read() method returns halt::R reader structure

Source

impl Readable for ICHIGH_SPEC

read() method returns ichigh::R reader structure

Source

impl Readable for ICLOW_SPEC

read() method returns iclow::R reader structure

Source

impl Readable for swm341_pac::timr0::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::timr0::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for swm341_pac::timr0::load::LOAD_SPEC

read() method returns load::R reader structure

Source

impl Readable for OCCR_SPEC

read() method returns occr::R reader structure

Source

impl Readable for OCMAT_SPEC

read() method returns ocmat::R reader structure

Source

impl Readable for PREDIV_SPEC

read() method returns prediv::R reader structure

Source

impl Readable for swm341_pac::timr0::reserved2::RESERVED2_SPEC

read() method returns reserved2::R reader structure

Source

impl Readable for swm341_pac::timr0::value::VALUE_SPEC

read() method returns value::R reader structure

Source

impl Readable for swm341_pac::timrg::en::EN_SPEC

read() method returns en::R reader structure

Source

impl Readable for HALL0V_SPEC

read() method returns hall0v::R reader structure

Source

impl Readable for HALL3V_SPEC

read() method returns hall3v::R reader structure

Source

impl Readable for HALLEN_SPEC

read() method returns hallen::R reader structure

Source

impl Readable for HALLIE_SPEC

read() method returns hallie::R reader structure

Source

impl Readable for HALLIF_SPEC

read() method returns hallif::R reader structure

Source

impl Readable for HALLSR_SPEC

read() method returns hallsr::R reader structure

Source

impl Readable for BAUD_SPEC

read() method returns baud::R reader structure

Source

impl Readable for swm341_pac::uart0::cfg::CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for swm341_pac::uart0::ctrl::CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for CTSCR_SPEC

read() method returns ctscr::R reader structure

Source

impl Readable for swm341_pac::uart0::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for FIFO_SPEC

read() method returns fifo::R reader structure

Source

impl Readable for LINCR_SPEC

read() method returns lincr::R reader structure

Source

impl Readable for RTSCR_SPEC

read() method returns rtscr::R reader structure

Source

impl Readable for TOCR_SPEC

read() method returns tocr::R reader structure

Source

impl Readable for DEVCR_SPEC

read() method returns devcr::R reader structure

Source

impl Readable for DEVIE_SPEC

read() method returns devie::R reader structure

Source

impl Readable for DEVIF_SPEC

read() method returns devif::R reader structure

Source

impl Readable for DEVSR_SPEC

read() method returns devsr::R reader structure

Source

impl Readable for EPCFG_SPEC

read() method returns epcfg::R reader structure

Source

impl Readable for EPIE_SPEC

read() method returns epie::R reader structure

Source

impl Readable for EPIF_SPEC

read() method returns epif::R reader structure

Source

impl Readable for swm341_pac::usbd::ffthr::FFTHR_SPEC

read() method returns ffthr::R reader structure

Source

impl Readable for swm341_pac::usbd::framenr::FRAMENR_SPEC

read() method returns framenr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep0::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep0::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep0::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep1::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep1::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep1::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep2::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep2::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep2::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep3::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep3::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep3::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep4::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep4::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep4::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep5::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep5::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep5::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep6::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep6::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep6::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep7::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep7::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep7::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep8::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep8::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep8::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep9::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep9::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep9::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep10::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep10::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep10::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep11::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep11::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep11::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep12::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep12::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep12::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep13::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep13::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep13::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep14::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep14::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep14::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::inep15::txcr::TXCR_SPEC

read() method returns txcr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep15::txsr::TXSR_SPEC

read() method returns txsr::R reader structure

Source

impl Readable for swm341_pac::usbd::inep15::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::usbd::outep0::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep1::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep2::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep3::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep4::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep5::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep6::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep7::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep8::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep9::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep10::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep11::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep12::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep13::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep14::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::outep15::rxcr::RXCR_SPEC

read() method returns rxcr::R reader structure

Source

impl Readable for swm341_pac::usbd::rxbuf::RXBUF_SPEC

read() method returns rxbuf::R reader structure

Source

impl Readable for RXSR_SPEC

read() method returns rxsr::R reader structure

Source

impl Readable for SETUPD1_SPEC

read() method returns setupd1::R reader structure

Source

impl Readable for SETUPD2_SPEC

read() method returns setupd2::R reader structure

Source

impl Readable for SETUPSR_SPEC

read() method returns setupsr::R reader structure

Source

impl Readable for TXBUF0__SPEC

read() method returns txbuf0_::R reader structure

Source

impl Readable for TXBUF1__SPEC

read() method returns txbuf1_::R reader structure

Source

impl Readable for TXBUF2__SPEC

read() method returns txbuf2_::R reader structure

Source

impl Readable for TXBUF3__SPEC

read() method returns txbuf3_::R reader structure

Source

impl Readable for TXBUF4__SPEC

read() method returns txbuf4_::R reader structure

Source

impl Readable for TXBUF5__SPEC

read() method returns txbuf5_::R reader structure

Source

impl Readable for TXBUF6__SPEC

read() method returns txbuf6_::R reader structure

Source

impl Readable for TXBUF7__SPEC

read() method returns txbuf7_::R reader structure

Source

impl Readable for TXBUF8__SPEC

read() method returns txbuf8_::R reader structure

Source

impl Readable for TXBUF9__SPEC

read() method returns txbuf9_::R reader structure

Source

impl Readable for TXBUF10__SPEC

read() method returns txbuf10_::R reader structure

Source

impl Readable for TXBUF11__SPEC

read() method returns txbuf11_::R reader structure

Source

impl Readable for TXBUF12__SPEC

read() method returns txbuf12_::R reader structure

Source

impl Readable for TXBUF13__SPEC

read() method returns txbuf13_::R reader structure

Source

impl Readable for TXBUF14__SPEC

read() method returns txbuf14_::R reader structure

Source

impl Readable for TXBUF15__SPEC

read() method returns txbuf15_::R reader structure

Source

impl Readable for swm341_pac::usbh::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for FFSZ_SPEC

read() method returns ffsz::R reader structure

Source

impl Readable for swm341_pac::usbh::ffthr::FFTHR_SPEC

read() method returns ffthr::R reader structure

Source

impl Readable for FRAMEIV_SPEC

read() method returns frameiv::R reader structure

Source

impl Readable for swm341_pac::usbh::framenr::FRAMENR_SPEC

read() method returns framenr::R reader structure

Source

impl Readable for FRAMERM_SPEC

read() method returns framerm::R reader structure

Source

impl Readable for swm341_pac::usbh::ie::IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for swm341_pac::usbh::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for OTGCSR_SPEC

read() method returns otgcsr::R reader structure

Source

impl Readable for PORTSR_SPEC

read() method returns portsr::R reader structure

Source

impl Readable for swm341_pac::usbh::rxbuf::RXBUF_SPEC

read() method returns rxbuf::R reader structure

Source

impl Readable for swm341_pac::usbh::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for TOKEN_SPEC

read() method returns token::R reader structure

Source

impl Readable for TXBUF_SPEC

read() method returns txbuf::R reader structure

Source

impl Readable for swm341_pac::usbh::txtrsz::TXTRSZ_SPEC

read() method returns txtrsz::R reader structure

Source

impl Readable for swm341_pac::wdt::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for FEED_SPEC

read() method returns feed::R reader structure

Source

impl Readable for swm341_pac::wdt::if_::IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for INTVAL_SPEC

read() method returns intval::R reader structure

Source

impl Readable for RSTVAL_SPEC

read() method returns rstval::R reader structure